@@ -11,6 +11,7 @@ import time
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Optional
+from urllib.parse import urljoin
 
 import requests
 from git import Git, Repo
@@ -115,8 +116,8 @@ class GitHubAuth:
                     )
 
                 # Get contributions token from Model Hub API
-                token_url = (
-                    f"{self.config.models.base_url}/api/github/contribution/app/token"
+                token_url = urljoin(
+                    self.config.models.base_url, "/api/github/contribution/app/token"
                 )
 
                 # Add timeout configuration
