@@ -19,11 +19,16 @@ class LazyGroup(click.Group):
             from .get import get_command  # noqa: PLC0415
 
             return get_command
+        elif name == "system-check":
+            from .system_check import system_check_command  # noqa: PLC0415
+
+            return system_check_command
+
         return None
 
     def list_commands(self, ctx):
         """List available commands without importing them."""
-        return ["list", "run", "get"]
+        return ["list", "run", "get", "system-check"]
 
 
 @click.group(cls=LazyGroup)
