@@ -8,10 +8,10 @@ from rich.console import Console
 
 from .api import BenchmarkMetric, BenchmarkRecord
 from .utils import (
+    BENCHMARK_BASE_COLUMNS,
     CACHE_PATH,
     CLIError,
     handle_cli_error,
-    handle_unexpected_error,
 )
 
 logger = logging.getLogger(__name__)
@@ -225,7 +225,7 @@ def load_cached_benchmark_results(
 @click.option(
     "-b",
     "--benchmark-key",
-    help="Filter by benchmark key (substring match with '*' wildcards, e.g. 'scvi*v1-tsv2*liver-label*pred')",
+    help="Retrieve by benchmark key (exact match). Mutually-exclusive with filter options.",
 )
 @click.option(
     "-m",
@@ -249,6 +249,11 @@ def load_cached_benchmark_results(
     default="table",
     help="Output format",
 )
+@click.option(
+    "--fit/--full",
+    default=True,
+    help="Column display for table format (default: fit). Use --full to show full column content; pair with a pager like 'less -S' for horizontal scrolling. Only applies to --format=table.",
+)
 @click.pass_context
 def get_command(
     ctx: click.Context,
@@ -257,6 +262,7 @@ def get_command(
     dataset_filter: Optional[str],
     task_filter: Optional[str],
     format: str,
+    fit: bool,
 ) -> None:
     """
     Fetch and display benchmark results from the API.
@@ -278,9 +284,9 @@ def get_command(
             )
 
         if benchmark_key:
-            from .api import fetch_benchmarks_by_key  # noqa: PLC0415
+            from .api import fetch_benchmark_by_key  # noqa: PLC0415
 
-            benchmark_record = fetch_benchmarks_by_key(benchmark_key)
+            benchmark_record = fetch_benchmark_by_key(benchmark_key)
             api_benchmarks = [benchmark_record]
         else:
             from .api import fetch_benchmarks_list  # noqa: PLC0415
@@ -307,6 +313,7 @@ def get_command(
                 console.print("No benchmarks found matching the specified filters.")
             return
 
+        # TODO: Use vcp.commands.benchmarks.utils.display_benchmark_results_table() when the API results format is brought into alignment with the cached results format.
         all_rows = []
         for benchmark in all_benchmarks:
             benchmark_dict = benchmark.model_dump()
@@ -333,22 +340,21 @@ def get_command(
         if format == "json":
             console.print(json.dumps(all_rows, indent=2, default=str))
         else:
-            ordered_columns = [
-                "benchmark_key",
-                "model_key",
-                "model_name",
-                "dataset_keys",
-                "dataset_names",
-                "task_key",
-                "task_name",
-                "metric",
-                "value",
-            ]
+            # Extend base columns with metric-specific columns
+            ordered_columns = BENCHMARK_BASE_COLUMNS + ["metric", "value"]
             from .utils import format_as_table  # noqa: PLC0415
 
-            console.print(format_as_table(all_rows, table_type=ordered_columns))
+            # Use wide console for --full to allow full column values
+            # With --fit (default), use normal console with max_width constraints
+            if not fit:
+                wide_console = Console(width=500)
+                wide_console.print(
+                    format_as_table(all_rows, table_type=ordered_columns, wrap=fit)
+                )
+            else:
+                console.print(
+                    format_as_table(all_rows, table_type=ordered_columns, wrap=fit)
+                )
 
     except CLIError as e:
         handle_cli_error(e)
-    except Exception as e:
-        handle_unexpected_error(e, "vcp benchmarks get")
