@@ -2,9 +2,10 @@ import hashlib
 import json
 import logging
 import subprocess
+import sys
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple, Union, get_args, get_origin
 
 import click
 import numpy as np
@@ -20,10 +21,48 @@ console = Console()
 # TODO: will be replaced when implementing https://czi.atlassian.net/browse/VC-3963
 CACHE_PATH = Path.home() / ".vcp" / "cache"
 
+# Column order for benchmark table outputs
+# Used by both 'benchmarks list' and 'benchmarks get' commands to ensure consistency
+BENCHMARK_BASE_COLUMNS = [
+    "benchmark_key",
+    "model_key",
+    "model_name",
+    "dataset_keys",
+    "dataset_names",
+    "task_key",
+    "task_name",
+]
+
+
+def _build_cache_dir_path(
+    model_uid: str,
+    dataset_uids: List[str],
+    task: Optional[str] = None,
+    task_run_id: Optional[str] = None,
+) -> Path:
+    datasets_cache_key = "_".join(sorted(dataset_uids))
+    if task:
+        cache_dir = (
+            CACHE_PATH
+            / model_uid
+            / datasets_cache_key
+            / "task_outputs"
+            / task
+            / str(task_run_id)
+        )
+    else:
+        cache_dir = CACHE_PATH / model_uid / datasets_cache_key
+    return cache_dir
+
 
 # TODO: Move all cache-related methods to a new cache.py module
 def save_to_cache(
-    model: str, dataset: str, task: Optional[str], data: Any, data_type: str = "auto"
+    model_key: str,
+    dataset_uids: List[str],
+    task: Optional[str],
+    data: Any,
+    data_type: str = "auto",
+    task_run_id: Optional[str] = None,
 ):
     """
     Save data to the local cache directory for a given model, dataset, and task.
@@ -35,7 +74,7 @@ def save_to_cache(
 
     Args:
         model (str): The model identifier/key.
-        dataset (str): The dataset identifier/key.
+        datasets (List[Dataset]): The datasets.
         task (Optional[str]): The task identifier/key. If None, data is stored at the
             model/dataset level without task_outputs subdirectory.
         data (Any): The data to cache. Can be a numpy array, dict, or AnnData object.
@@ -52,10 +91,7 @@ def save_to_cache(
         CLIError: If the data type is unsupported for caching or if data cannot be serialized.
     """
 
-    if task:
-        cache_dir = CACHE_PATH / model / dataset / "task_outputs" / task
-    else:
-        cache_dir = CACHE_PATH / model / dataset
+    cache_dir = _build_cache_dir_path(model_key, dataset_uids, task, task_run_id)
 
     cache_dir.mkdir(parents=True, exist_ok=True)
 
@@ -67,6 +103,7 @@ def save_to_cache(
     elif data_type == "results" or (data_type == "auto" and isinstance(data, dict)):
         file_path = cache_dir / "results.json"
         file_path.write_text(json.dumps(data, indent=2, default=str), encoding="utf-8")
+    # TODO: remove this case; never used
     elif data_type == "dataset" or (
         data_type == "auto" and hasattr(data, "write_h5ad")
     ):
@@ -76,8 +113,13 @@ def save_to_cache(
         raise CLIError(f"Unsupported data type for caching: {type(data)}")
 
 
+# TODO: Should return None on cache miss instead of raising FileNotFoundError; cache misses are normal behavior
 def load_from_cache(
-    model: str, dataset: str, task: Optional[str], data_type: str
+    model: str,
+    dataset_uids: List[str],
+    task: Optional[str],
+    data_type: str,
+    task_run_id: Optional[str] = None,
 ) -> Any:
     """
     Load cached data for a given model, dataset, and task from the local cache directory.
@@ -88,7 +130,7 @@ def load_from_cache(
 
     Args:
         model (str): The model identifier/key.
-        dataset (str): The dataset identifier/key.
+        dataset_keys (List[str]): The dataset identifiers/keys.
         task (Optional[str]): The task identifier/key. If None, loads from the
             model/dataset level directory.
         data_type (str): Type of data to load. Must be one of:
@@ -105,10 +147,7 @@ def load_from_cache(
         CLIError: If the data_type is not supported.
     """
 
-    if task:
-        cache_dir = CACHE_PATH / model / dataset / "task_outputs" / task
-    else:
-        cache_dir = CACHE_PATH / model / dataset
+    cache_dir = _build_cache_dir_path(model, dataset_uids, task, task_run_id)
 
     if data_type == "embeddings":
         file_path = cache_dir / "embeddings.npy"
@@ -119,10 +158,12 @@ def load_from_cache(
         return np.load(file_path)
     elif data_type == "results":
         file_path = cache_dir / "results.json"
+        logger.debug(f"Trying to load cached results from {file_path}")
         if not file_path.exists():
             raise FileNotFoundError(f"Results not found: {file_path}")
         return json.loads(file_path.read_text(encoding="utf-8"))
     elif data_type == "dataset":
+        # TODO: remove this case; never used
         file_path = cache_dir / "dataset.h5ad"
 
         if not file_path.exists():
@@ -134,24 +175,20 @@ def load_from_cache(
         raise CLIError(f"Unsupported data type: {data_type}")
 
 
-def get_cache_dir(model: str, dataset: str, task: Optional[str] = None) -> Path:
+def get_cell_representation_cache_dir(model: str, dataset_uids: List[str]) -> Path:
     """
-    Get (and create if necessary) the cache directory for a given model, dataset, and task.
+    Get (and create if necessary) the cache directory for a given model and dataset, where cell representations are stored.
 
-    Constructs the path ~/.vcp/cache/<model>/<dataset>/<task>/ and ensures it exists.
+    Constructs the path ~/.vcp/cache/<model>/<dataset_keys>/ and ensures it exists.
 
     Args:
         model (str): The model key.
-        dataset (str): The dataset key.
-        task (Optional[str]): The task key. If None, returns the model/dataset directory.
+        dataset_keys (List[str]): The dataset keys.
 
     Returns:
         Path: The Path object for the cache directory.
     """
-    if task:
-        cache_dir = CACHE_PATH / model / dataset / "task_outputs" / task
-    else:
-        cache_dir = CACHE_PATH / model / dataset
+    cache_dir = _build_cache_dir_path(model, dataset_uids)
     cache_dir.mkdir(parents=True, exist_ok=True)
     return cache_dir
 
@@ -184,7 +221,11 @@ def generate_benchmark_key(
 
 
 def format_as_table(
-    rows: List[Dict], table_type: str = "auto", depth: int = 2
+    rows: List[Dict],
+    table_type: str = "auto",
+    depth: int = 2,
+    table_title: Optional[str] = "Benchmarks",
+    wrap: bool = True,
 ) -> Table:
     """
     Format a list of dictionaries as a Rich table for console display.
@@ -201,6 +242,9 @@ def format_as_table(
             Defaults to "auto".
         depth (int, optional): Maximum depth for flattening nested dictionaries.
             Nested keys become "parent.child" column names. Defaults to 2.
+        wrap (bool, optional): If True, descriptive columns wrap within max_width=24.
+            If False, all columns display full values without width constraints.
+            Defaults to True.
 
     Returns:
         Table: A Rich Table object ready for console display with proper formatting.
@@ -229,13 +273,43 @@ def format_as_table(
     else:
         columns = sorted(all_columns)
 
+    # Use expand=False to prevent table from being squeezed to fit terminal width
     tbl = Table(
-        show_header=True, header_style="bold magenta", title="Benchmarks", expand=True
+        show_header=True, header_style="bold magenta", title=table_title, expand=False
     )
+
+    # Key/ID columns should never wrap or truncate (for easy copying)
+    no_wrap_columns = {
+        "benchmark_key",
+        "model_key",
+        "dataset_keys",
+        "task_key",
+        "metric",
+    }
+
     for col in columns:
         header_text = str(col).replace("_", " ").title()
         min_width = max(12, len(header_text))
-        tbl.add_column(header_text, overflow="fold", no_wrap=False, min_width=min_width)
+
+        if wrap:
+            # With wrapping: Key columns show full value, descriptive columns wrap within max_width
+            if col in no_wrap_columns:
+                tbl.add_column(
+                    header_text, overflow="visible", no_wrap=True, min_width=min_width
+                )
+            else:
+                tbl.add_column(
+                    header_text,
+                    overflow="fold",
+                    no_wrap=False,
+                    min_width=min_width,
+                    max_width=24,
+                )
+        else:
+            # Without wrapping: All columns show full values without width constraints
+            tbl.add_column(
+                header_text, overflow="visible", no_wrap=True, min_width=min_width
+            )
 
     def get_value(row: Dict, col: str):
         keys = col.split(".")
@@ -366,6 +440,9 @@ def mutually_exclusive(*other_names: str):
         current_has_value = False
         if isinstance(value, tuple):
             current_has_value = len(value) > 0
+        elif isinstance(value, bool):
+            # For boolean flags, only consider True as "has value"
+            current_has_value = value is True
         else:
             current_has_value = value is not None
 
@@ -376,6 +453,9 @@ def mutually_exclusive(*other_names: str):
 
                 if isinstance(other_value, tuple):
                     other_has_value = len(other_value) > 0
+                elif isinstance(other_value, bool):
+                    # For boolean flags, only consider True as "has value"
+                    other_has_value = other_value is True
                 else:
                     other_has_value = other_value is not None
 
@@ -448,14 +528,121 @@ def validate_benchmark_filters(
             handle_cli_error(CLIError(f"{name} contains invalid characters"))
 
 
-# TODO: This should just report and non re-raise error to avoid double logging
 def handle_cli_error(error: CLIError) -> None:
+    """Print CLI error to console and exit without raising, to avoid double logging."""
     console.print(f"[red]Error:[/red] {error}")
-    raise error
+    sys.exit(1)
 
 
-# TODO: This should just report and non re-raise error to avoid double logging
-def handle_unexpected_error(error: Exception, command_name: str) -> None:
-    console.print(f"[red]Unexpected error:[/red] {error}")
-    console.print("[dim]Check logs for details or contact support.[/dim]")
-    raise error
+def get_first_sentence(text: str) -> str:
+    """Extract the first sentence from a docstring.
+
+    Args:
+        text: The full text to extract from.
+
+    Returns:
+        The first sentence, ending with a period.
+    """
+    # Remove all newlines and collapse multiple spaces
+    single_line = " ".join(text.split())
+
+    # Find the first sentence (ends with period, question mark, or exclamation)
+    for i, char in enumerate(single_line):
+        if char in ".!?" and (
+            i == len(single_line) - 1 or single_line[i + 1].isspace()
+        ):
+            return single_line[: i + 1]
+
+    # If no sentence ending found, return the text (shouldn't happen with well-formed docstrings)
+    return single_line
+
+
+def display_benchmark_results_table(
+    enriched_results: Dict[str, Any], console: Console, wrap: bool = True
+) -> None:
+    """Display benchmark run results as a formatted table.
+
+    Args:
+        enriched_results: Enriched results dict (JSON types only, no Pydantic models). See _build_enriched_results() for structure.
+        console: Rich console for output
+        wrap: If True, wrap descriptive columns. If False, show full values. Defaults to True.
+    """
+
+    run_spec = enriched_results["run_specification"]
+    result_metrics = enriched_results["result_metrics"]
+    runtime_metrics = enriched_results.get("runtime_metrics", {})
+
+    # Determine model key for display
+    model_details = run_spec.get("model_details", {})
+    if model_details and model_details.get("key"):
+        model_key = model_details["key"]
+    elif run_spec.get("run_baseline"):
+        model_key = "baseline"
+    elif run_spec.get("cell_representations"):
+        model_key = "user-cell-representation"
+    else:
+        raise CLIError("Invalid run specification: missing model details")
+
+    # Determine dataset keys for display
+    dataset_keys = []
+    for d in run_spec.get("datasets", []):
+        if d.get("key"):
+            dataset_keys.append(d["key"])
+        elif d.get("user_dataset"):
+            path = d["user_dataset"].get("path", "")
+            dataset_keys.append(f"user:{Path(path).name}" if path else "user-dataset")
+        else:
+            dataset_keys.append("unknown")
+
+    # Print summary information
+    console.print(f"\n[bold]Model:[/bold] {model_key}")
+    console.print(f"[bold]Datasets:[/bold] {', '.join(dataset_keys)}")
+    console.print(f"[bold]Task:[/bold] {run_spec.get('task_key', 'unknown')}")
+    if runtime_metrics:
+        elapsed = runtime_metrics.get("elapsed_time_secs", 0)
+        memory = runtime_metrics.get("max_memory_mib", 0)
+        console.print(f"[bold]Runtime:[/bold] {elapsed:.2f} secs, {memory:.2f} MiB")
+    console.print()
+
+    # Build rows for table
+    if not result_metrics:
+        console.print("[yellow]No metrics to display[/yellow]")
+        return
+
+    rows = []
+    for metric in result_metrics:
+        row = {
+            "metric_type": metric.get("metric_type", "unknown"),
+            "value": metric.get("value", 0),
+        }
+        rows.append(row)
+
+    # Display table
+    ordered_columns = ["metric_type", "value"]
+    table = format_as_table(
+        rows, table_type=ordered_columns, table_title="Benchmark Results", wrap=wrap
+    )
+    console.print(table)
+
+
+def type_to_click_info(param_type: Any) -> Tuple[click.ParamType, bool]:
+    """Infers click parameter type from a Python type annotation."""
+    origin = get_origin(param_type)
+
+    if origin is Union:
+        args = get_args(param_type)
+        blank_args = [arg for arg in args if arg is not type(None)]
+        if blank_args:
+            return type_to_click_info(blank_args[0])
+
+    if str(param_type).startswith("typing.Literal"):
+        return click.Choice([str(a) for a in get_args(param_type)]), False
+    if origin in (list, List, tuple, Tuple):
+        return click.STRING, True
+    if param_type is bool:
+        return click.BOOL, False
+    if param_type is int:
+        return click.INT, False
+    if param_type is float:
+        return click.FLOAT, False
+    return click.STRING, False  # Default to STRING for flexibility
