@@ -39,14 +39,14 @@ def ensure_authentication(ctx):
 
 DATA_HELP = f"""
 {click.style("Data usage workflow", fg="cyan", bold=True)}\n
-{click.style("1.", fg="cyan", bold=True)} List searchable fields: {click.style("vcp data search --help", fg="green")}\n
+{click.style("1.", fg="cyan", bold=True)} List searchable fields: {click.style("vcp data metadata-list", fg="green")}\n
 {click.style("2.", fg="cyan", bold=True)} Survey datasets based on searchable field: {click.style("vcp data summary $FIELD", fg="green")}\n
 {click.style("3.", fg="cyan", bold=True)} Search for datasets: {click.style("vcp data search '$FIELD:$VALUE'", fg="green")}\n
 {click.style("3.a", fg="cyan", bold=True)} ... Restrict search: {click.style("vcp data search '$FIELD:$VALUE_1 AND $FIELD:$VALUE_2'", fg="green")}\n
-{click.style("3.b", fg="cyan", bold=True)} ... Expand search: {click.style("vcp data search '($FIELD:$VALUE_1 OR $FIELD:$VALUE_3 ) AND ($FIELD:$VALUE_3)'", fg="green")}\n
+{click.style("3.b", fg="cyan", bold=True)} ... Expand search: {click.style("vcp data search '($FIELD:$VALUE_1 OR $FIELD:$VALUE_2) AND ($FIELD:$VALUE_3)'", fg="green")}\n
 {click.style("4", fg="cyan", bold=True)} Describe a single dataset: {click.style("vcp data describe $DATASET_ID", fg="green")}\n
 {click.style("5", fg="cyan", bold=True)} Download:\n
-{click.style("5.a", fg="cyan", bold=True)} ... a single dataset: {click.style("vcp data download $DATASET_ID", fg="green")}\n
+{click.style("5.a", fg="cyan", bold=True)} ... a single dataset: {click.style("vcp data download --id $DATASET_ID", fg="green")}\n
 {click.style("5.b", fg="cyan", bold=True)} ... multiple datasets matching search: {click.style("vcp data search $QUERY --download", fg="green")}\n
 """
 
