@@ -13,7 +13,9 @@ from vcp.datasets.api import (
     CroissantFileObject,
     CroissantLiteModel,
     CrossModalitySchemaFields,
+    HcsMetadata,
     create_cross_modality_fields_from_dataset,
+    extract_hcs_metadata,
     get_dataset_api,
     get_dataset_api_raw,
 )
@@ -38,13 +40,13 @@ TOKEN_MANAGER = TokenManager()
 logger = logging.getLogger(__name__)
 
 
-# extract DOI from citeAs field or bibtex string
+# extract DOI or arxiv link from citeAs field or bibtex string
 def extract_doi(cite_as: Optional[str]) -> Optional[str]:
-    """Extract DOI from citeAs field or bibtex string."""
+    """Extract DOI or arxiv link from citeAs field or bibtex string."""
     if not cite_as:
         return None
 
-    # DOI regex pattern
+    # DOI regex pattern (priority 1)
     doi_pattern = r"10\.\d{4,9}/[-._;()/:A-Z0-9]+"
 
     # First try to find DOI directly in the string
@@ -63,6 +65,12 @@ def extract_doi(cite_as: Optional[str]) -> Optional[str]:
             if re.match(doi_pattern, doi_candidate, re.IGNORECASE):
                 return doi_candidate
 
+    # If no DOI found, try to extract arxiv link (priority 2)
+    arxiv_pattern = r"https?://arxiv\.org/abs/[\d.v]+"
+    arxiv_match = re.search(arxiv_pattern, cite_as, re.IGNORECASE)
+    if arxiv_match:
+        return arxiv_match.group(0)
+
     return None
 
 
@@ -214,8 +222,16 @@ def create_basic_info_table(record: Any) -> Table:
 
 
 # print table of biological metadata
-def create_biological_metadata_table(xms_data: CrossModalitySchemaFields) -> Table:
-    """Create the Biological Metadata table using CrossModalitySchemaFields."""
+def create_biological_metadata_table(
+    xms_data: CrossModalitySchemaFields,
+    hcs_data: Optional[HcsMetadata] = None,
+) -> Table:
+    """
+    Create the Biological Metadata table.
+
+    Displays XMS (Cross-Modality Schema) fields followed by non-XMS
+    HCS (High Content Screening) metadata fields (if present).
+    """
     tw = _term_width()
 
     table = Table(
@@ -229,18 +245,22 @@ def create_biological_metadata_table(xms_data: CrossModalitySchemaFields) -> Tab
     table.add_column("Field", style="cyan", no_wrap=True, width=35)
     table.add_column("Value", overflow="fold", max_width=tw - 40)
 
-    # Get biological metadata fields from CrossModalitySchemaFields
-    # These will be in the order they were defined in the model
+    # Add XMS (Cross-Modality Schema) fields first
     xms_fields = CrossModalitySchemaFields.model_fields
-
-    # Iterate through fields in their definition order
     for field_name, field_info in xms_fields.items():
-        # Get the value from the xms_data instance
         value = getattr(xms_data, field_name, None)
-        # Use alias if available, otherwise format field name
         display_name = field_info.alias or field_name.replace("_", " ").title()
         table.add_row(display_name, format_list_values(value))
 
+    # Add HCS metadata fields (non-XMS) if present
+    if hcs_data:
+        hcs_fields = HcsMetadata.model_fields
+        for field_name, field_info in hcs_fields.items():
+            value = getattr(hcs_data, field_name, None)
+            if value:  # Only show if has a value
+                display_name = field_info.alias or field_name.replace("_", " ").title()
+                table.add_row(display_name, format_list_values(value))
+
     return table
 
 
@@ -361,11 +381,17 @@ def describe_command(dataset_id: str, full: bool = False, raw: bool = False):
     console.print(basic_table)
     console.print()
 
-    # Extract biological metadata using factory function
+    # Extract XMS (Cross-Modality Schema) biological metadata
     xms_data = create_cross_modality_fields_from_dataset(record)
 
-    # Biological Metadata Table
-    bio_table = create_biological_metadata_table(xms_data)
+    # Extract non-XMS HCS (High Content Screening) metadata
+    hcs_dict = extract_hcs_metadata(record.md)
+    hcs_data = None
+    if hcs_dict:  # Only create instance if we have data
+        hcs_data = HcsMetadata.model_validate(hcs_dict)
+
+    # Biological Metadata Table (includes both XMS and non-XMS HCS fields)
+    bio_table = create_biological_metadata_table(xms_data, hcs_data)
     console.print(bio_table)
     console.print()
 
