@@ -124,7 +124,7 @@ SEARCH_EXAMPLES = f"""
 \t{click.style("vcp data search 'tissue:hard palate' --download", fg="green")} \n
 \t ... equivalent to: {click.style("vcp data download --query 'tissue:hard palate'", fg="green")} \n
 - Combine --exact and --download:\n
-\t{click.style("vcp data search 'bed nucleus of stria terminalis' --exact", fg="green")} \n
+\t{click.style("vcp data search 'bed nucleus of stria terminalis' --exact --download", fg="green")} \n
 \t ... equivalent to: {click.style("vcp data download --query 'bed nucleus of stria terminalis' --exact", fg="green")} \n
 \n
 \n
@@ -205,6 +205,12 @@ FREE_FIELDS = f"""
     is_flag=True,
     help="Match term exactly (no partial matches)",
 )
+@click.option(
+    "--latest-version/--all-versions",
+    default=True,
+    is_flag=True,
+    help="Specifies if all or just the latest version of each dataset (if multiple versions exist) should be returned. Defaults to --latest-version.",
+)
 @click.pass_context
 @with_error_handling(resource_type="datasets", operation="data search")
 def search_command(
@@ -214,6 +220,7 @@ def search_command(
     full: bool,
     outdir: str,
     exact: bool,
+    latest_version: bool,
 ):
     """
     Search for authorized datasets by TERM.\n
@@ -293,7 +300,9 @@ def search_command(
     page_limit = 10  # max number of records per page
 
     while True:
-        resp = search_data_api(tokens.id_token, term, page_limit, cursor, exact)
+        resp = search_data_api(
+            tokens.id_token, term, page_limit, cursor, exact, latest_version
+        )
         cursor = resp.cursor
 
         if first:
