@@ -85,9 +85,20 @@ XMS_CHOICE = FriendlyChoice(
 @click.command(epilog=SUMMARY_EXAMPLES)
 @click.argument("field", type=XMS_CHOICE)
 @click.option("--query", "-q", default="*", help="Search query to filter datasets.")
+@click.option(
+    "--latest-version/--all-versions",
+    default=True,
+    is_flag=True,
+    help="Specifies if all or just the latest version of each dataset (if multiple versions exist) should be counted. Defaults to --latest-version.",
+)
 @click.pass_context
 @with_error_handling(resource_type="datasets", operation="data summary")
-def summary_command(ctx: click.Context, field: str, query: str):
+def summary_command(
+    ctx: click.Context,
+    field: str,
+    query: str,
+    latest_version: bool,
+):
     """Summarize counts of matched datasets against a specified FIELD."""
 
     # Validate search query (only if not wildcard)
@@ -100,7 +111,7 @@ def summary_command(ctx: click.Context, field: str, query: str):
 
     # issue request
     summary: SummaryResponse = summary_data_api(
-        id_token=tokens.id_token, field=field, term=query
+        id_token=tokens.id_token, field=field, term=query, latest_version=latest_version
     )
 
     # pagination for users
