@@ -21,6 +21,22 @@ from .models import SubmissionResponse
 from .utils import validate_version_format
 from .workspace import ModelWorkspaceState
 
+COPIER_EXCLUDE_PATTERNS = [
+    "copier.yaml",
+    "copier.yml",
+    "~*",
+    "*.py[co]",
+    "__pycache__",
+    ".git",
+    ".DS_Store",
+    ".svn",
+    "example-model-configs",
+    "LICENSE.md",
+    "README.md",
+    "SECURITY.md",
+    "render_templates.py",
+]
+
 logger = logging.getLogger(__name__)
 console = Console()
 
@@ -833,6 +849,7 @@ def init_command(
                 overwrite=True,
                 defaults=True,  # Use defaults for unspecified fields
                 vcs_ref="main",
+                exclude=COPIER_EXCLUDE_PATTERNS,
             )
 
             console.print("[green]Template files generated successfully![/green]")
