@@ -1,4 +1,3 @@
-import json
 from typing import Literal, Optional
 
 import click
@@ -33,10 +32,11 @@ def list_command(
     if verbose and format != "json":
         console.print(f"Model Hub Base URL: {config_obj.models.base_url}")
 
-    response = fetch_models_list(modelhub_base_url=config_obj.models.base_url)
+    response = fetch_models_list(config=config_obj)
 
     if format == "json":
-        console.print(json.dumps(response.model_dump(), indent=2))
+        # Use Pydantic's model_dump_json for proper UUID serialization
+        console.print(response.model_dump_json(indent=2))
     else:
         table = format_models_table(response.models)
         console.print(table)
