@@ -97,122 +97,6 @@ def validate_version_format(version: str) -> bool:
     return False
 
 
-def download_single_file(
-    download_url: str,
-    output_path: str,
-    filename: Optional[str] = None,
-    model: str = "",
-    version: str = "",
-    api_url: str = "",
-    headers: dict = None,
-    timeout: int = 1800,
-    verbose: bool = False,
-    show_progress: bool = True,
-) -> bool:
-    """
-    Download a single file using a presigned S3 URL.
-
-    Args:
-        download_url: The presigned S3 URL
-        output_path: Directory path to save the downloaded file
-        filename: Optional filename to use
-        model: Model name (unused in current implementation)
-        version: Model version (unused in current implementation)
-        api_url: API URL (unused in current implementation)
-        headers: Auth headers (unused in current implementation)
-        timeout: Download timeout
-        verbose: Whether to show verbose output
-        show_progress: Whether to show progress bar
-
-    Returns:
-        True if download successful, False otherwise
-    """
-    try:
-        if verbose:
-            console.print(f"[blue]Downloading from {download_url}[/blue]")
-
-        response = requests.get(download_url, timeout=timeout, stream=True)
-        response.raise_for_status()
-
-        # Determine filename
-        if not filename:
-            parsed = urlparse(download_url)
-            filename = os.path.basename(parsed.path) or "downloaded_file"
-
-        output_file = os.path.join(output_path, filename)
-        os.makedirs(output_path, exist_ok=True)
-
-        # Simple download without progress for now
-        with open(output_file, "wb") as f:
-            for chunk in response.iter_content(chunk_size=8192):
-                if chunk:
-                    f.write(chunk)
-
-        if verbose:
-            console.print(f"[green]Downloaded: {output_file}[/green]")
-
-        return True
-
-    except Exception as e:
-        if verbose:
-            console.print(f"[red]Download failed: {str(e)}[/red]")
-        return False
-
-
-def download_multiple_files(
-    all_files: List[Dict[str, Any]],
-    output_path: str,
-    model: str,
-    version: str,
-    timeout: int = 1800,
-    verbose: bool = False,
-) -> bool:
-    """
-    Download multiple files.
-
-    Args:
-        all_files: List of file info dictionaries
-        output_path: Directory to save files
-        model: Model name
-        version: Model version
-        timeout: Download timeout
-        verbose: Whether to show verbose output
-
-    Returns:
-        True if all downloads successful, False otherwise
-    """
-    success_count = 0
-
-    for file_info in all_files:
-        download_url = file_info.get("download_url")
-        filename = file_info.get("filename")
-
-        if not download_url:
-            if verbose:
-                console.print(f"[yellow]No download URL for {filename}[/yellow]")
-            continue
-
-        success = download_single_file(
-            download_url,
-            output_path,
-            filename,
-            model,
-            version,
-            "",
-            {},
-            timeout,
-            verbose,
-            True,
-        )
-
-        if success:
-            success_count += 1
-        elif verbose:
-            console.print(f"[red]Failed to download {filename}[/red]")
-
-    return success_count == len(all_files)
-
-
 # Production-grade file upload constants
 MAX_PARALLEL_UPLOADS = 5  # Number of concurrent uploads
 UPLOAD_TIMEOUT = 3600  # 60 minutes base timeout per file
@@ -364,8 +248,7 @@ def scan_directory_structure(data_path: str) -> List[Dict[str, Any]]:
                 "relative_path": str(relative_path),
                 "absolute_path": str(file_path),
                 "file_size": file_stats.st_size,
-                "last_modified": datetime.fromtimestamp(file_stats.st_mtime).isoformat()
-                + "Z",
+                "last_modified": f"{datetime.fromtimestamp(file_stats.st_mtime).isoformat()}Z",
             })
 
     return files_info
@@ -2019,24 +1902,34 @@ def format_models_table(models: list[ModelResponse]) -> Table:
     table = Table(show_header=True, header_style="bold magenta")
     table.add_column("Model Name")
     table.add_column("Version")
-    table.add_column("Description")
+    table.add_column("Variants")
 
     for model in models:
         if model.versions:
             # Add first version with model name
             first_version = model.versions[0]
+            variant_names = (
+                ", ".join(v.name for v in first_version.variants)
+                if first_version.variants
+                else "N/A"
+            )
             table.add_row(
                 model.name,
                 first_version.version,
-                first_version.description or "N/A",
+                variant_names,
             )
 
             # Add remaining versions with empty model name
             for version in model.versions[1:]:
+                variant_names = (
+                    ", ".join(v.name for v in version.variants)
+                    if version.variants
+                    else "N/A"
+                )
                 table.add_row(
                     "",
                     version.version,
-                    version.description or "N/A",
+                    variant_names,
                 )
         else:
             # Model with no versions
