@@ -9,22 +9,25 @@ import json
 import logging
 import os
 import subprocess
-import time
 from pathlib import Path
 from typing import Dict, Tuple
 
-import yaml
 from rich.console import Console
 from rich.table import Table
 
 from .git_operations import GitOperations
-from .utils import validate_init_command_ran, validate_stage_command_ran
+from .utils import (
+    load_model_metadata,
+    validate_init_command_ran,
+    validate_metadata_files,
+    validate_stage_command_ran,
+)
 
 logger = logging.getLogger(__name__)
 console = Console()
 
 
-class ModelWorkflowAssistant:
+class ModelWorkflowAssistant:  # FIXME: This should be a dataclass
     """Assistant for guiding users through the VCP model workflow."""
 
     def __init__(self, config=None):
@@ -32,13 +35,14 @@ class ModelWorkflowAssistant:
         # Cache for validation results to avoid duplicate error messages
         self._validation_cache = {}
         self.config = config
-        self.workflow_steps = {
+        self.workflow_steps = {  # FIXME: These should be instances of a dataclass
             1: {
                 "command": "init",
                 "name": "Initialize Model",
                 "description": "Setup a new workdir for model packaging",
                 "next_step": "metadata",
                 "validation": self._validate_init_step,
+                "optional": False,
             },
             2: {
                 "command": "metadata",
@@ -46,6 +50,7 @@ class ModelWorkflowAssistant:
                 "description": "Edit and validate metadata files",
                 "next_step": "weights",
                 "validation": self._validate_metadata_step,
+                "optional": False,
             },
             3: {
                 "command": "weights",
@@ -53,6 +58,7 @@ class ModelWorkflowAssistant:
                 "description": "Copy model weights under model_data directory",
                 "next_step": "package",
                 "validation": self._validate_copy_weights_step,
+                "optional": True,
             },
             4: {
                 "command": "package",
@@ -60,6 +66,7 @@ class ModelWorkflowAssistant:
                 "description": "Package the model",
                 "next_step": "stage",
                 "validation": self._validate_package_step,
+                "optional": True,
             },
             5: {
                 "command": "stage",
@@ -67,6 +74,7 @@ class ModelWorkflowAssistant:
                 "description": "Stage model artifacts",
                 "next_step": "submit",
                 "validation": self._validate_stage_step,
+                "optional": False,
             },
             6: {
                 "command": "submit",
@@ -74,6 +82,7 @@ class ModelWorkflowAssistant:
                 "description": "Submit model for review",
                 "next_step": None,
                 "validation": self._validate_submit_step,
+                "optional": False,
             },
         }
 
@@ -389,74 +398,37 @@ class ModelWorkflowAssistant:
             # Check if this is a resubmission workflow
             is_valid, _metadata_path, metadata = self._get_cached_validation(work_dir)
             if is_valid and metadata.get("resubmit", False):
-                # For resubmission, check if files have been edited
+                # Resubmission workflow, check if files have been edited
                 return self._validate_resubmit_file_editing(work_dir)
 
-            # Original validation logic for initial submissions
+            # Initial submission workflow
             work_path = Path(work_dir)
-            metadata_file = work_path / "model_card_docs/model_card_metadata.yaml"
+            # Attempt validation
+            metadata_validates = False
+            try:
+                result = validate_metadata_files(
+                    str(work_path), self.config, verbose=False
+                )
+                metadata_validates = result.success
+            except Exception as e:
+                # Config missing, auth failed, files not found, etc. - all treated as not validated
+                logger.debug(f"Metadata validation failed: {e}")
 
-            if not metadata_file.exists():
+            # If validation passes, step is complete
+            if metadata_validates:
                 return (
-                    False,
-                    "Make sure you are in the root of your model directory. Please ensure model_card_metadata.yaml exists.",
-                    {},
+                    True,
+                    "Metadata step completed successfully.\n\n",
+                    {"validated": True},
                 )
 
-            # Check if key files have been modified (not just template files)
-            key_files = [
-                "model_card_docs/model_card_metadata.yaml",
-                "README.md",
-                "requirements.txt",
-            ]
+            # If validation fails, show message to review files
+            message = "Please review metadata files:\n"
+            message += "      • model_card_docs/model_card_metadata.yaml\n"
+            message += "      • model_card_docs/model_card_details.md\n"
+            message += "\n[yellow]Tip:[/yellow] Run [cyan]vcp model validate-metadata[/cyan] to check your metadata before moving on to the next step."
 
-            modified_files = []
-            for file_path in key_files:
-                full_path = work_path / file_path
-                if full_path.exists():
-                    # Check if file has been modified (basic check)
-                    stat = full_path.stat()
-                    # If file was modified in last 24 hours, consider it edited
-
-                    if time.time() - stat.st_mtime < 86400:  # 24 hours
-                        modified_files.append(file_path)
-
-            if not modified_files:
-                return (
-                    False,
-                    "No key files appear to have been edited. Please edit model metadata, documentation, and configuration files.",
-                    {},
-                )
-
-            # Basic validation - check if required fields are present
-
-            with open(metadata_file, "r") as f:
-                metadata = yaml.safe_load(f)
-
-            required_fields = [
-                "model_display_name",
-                "model_version",
-                "model_description",
-            ]
-            missing_fields = [
-                field for field in required_fields if not metadata.get(field)
-            ]
-
-            if missing_fields:
-                return (
-                    False,
-                    f"Missing required metadata fields: {missing_fields}. Please complete the metadata file.",
-                    {
-                        "missing_fields": missing_fields,
-                        "modified_files": modified_files,
-                    },
-                )
-
-            return (
-                True,
-                f"Metadata step completed. Modified: {', '.join(modified_files)}. All required fields are present.",
-                {"validated_fields": required_fields, "modified_files": modified_files},
-            )
+            return (False, message, {})
 
         except Exception as e:
             return False, f"Error validating metadata step: {e}", {}
@@ -465,6 +437,14 @@ class ModelWorkflowAssistant:
         """Validate that copy weights step was completed successfully."""
         try:
             work_path = Path(work_dir)
+            metadata = load_model_metadata(work_dir)
+
+            if metadata.get("skip_packaging", False):
+                return (
+                    True,
+                    "Copy weights step skipped because `skip_packaging=True`",
+                    {"items_count": 0},
+                )
 
             # Find mlflow package directory
             # TODO: remove wildcard from mlflow_pkg. Unnecessary and only used for backwards compatibility with testing repos
@@ -581,6 +561,14 @@ class ModelWorkflowAssistant:
         """Validate that package step was completed successfully (includes package creation and validation)."""
         try:
             work_path = Path(work_dir)
+            metadata = load_model_metadata(work_dir)
+
+            if metadata.get("skip_packaging", False):
+                return (
+                    True,
+                    "Package validation skipped because `skip_packaging=True`",
+                    {"items_count": 0},
+                )
 
             # Check if mlflow_pkg directory exists
             # TODO: remove wildcard from mlflow_pkg. Unnecessary and only used for backwards compatibility with testing repos
@@ -912,6 +900,9 @@ class ModelWorkflowAssistant:
             if step_num in status["completed_steps"]:
                 status_icon = "✅ Completed"
                 status_style = "green"
+            elif step_info["optional"]:
+                status_icon = "🔷 Optional"
+                status_style = "dim"
             elif step_num == status["current_step"] + 1:
                 status_icon = "🔄 Next"
                 status_style = "yellow"
