@@ -1,4 +1,3 @@
-import typing
 from functools import lru_cache
 from typing import Any, Dict, List, Optional, Union
 from urllib.parse import urljoin
@@ -146,6 +145,31 @@ class CrossModalitySchemaFields(BaseModel):
     model_config = ConfigDict(populate_by_name=True)
 
 
+class HcsMetadata(BaseModel):
+    """
+    Non-XMS metadata for High Content Screening (HCS) datasets.
+
+    These fields are not part of the Cross-Modality Schema but provide
+    additional context for HCS datasets like OrganelleBox that include
+    experiment and well-level metadata.
+
+    NOTE: Field order determines display order in CLI output.
+    """
+
+    well_id: Optional[List[str]] = Field(
+        default=None,
+        alias="Well ID",
+        description="Identifier for the well in the HCS experiment",
+    )
+    experiment_name: Optional[List[str]] = Field(
+        default=None,
+        alias="Experiment Name",
+        description="Name of the HCS experiment",
+    )
+
+    model_config = ConfigDict(populate_by_name=True)
+
+
 class DataItem(DataItemSimplified, CrossModalitySchemaFields):
     """Data item with both basic fields and biological metadata"""
 
@@ -237,14 +261,18 @@ def search_data_api(
     limit: int,
     cursor: Optional[str] = None,
     exact: bool = False,
+    latest_version: bool = True,
 ) -> SearchResponse:
-    processed_term = _process_search_term(term, exact) + " AND latest_version:true"
+    processed_term = _process_search_term(term, exact)
+    if latest_version:
+        processed_term += " AND latest_version:true"
 
     params = {
         "query": processed_term,
         "use_cursor": "true",
         "download": "true",  # always true to get creds
         "scout": not bool(cursor),  # only scout on first page
+        "limit": limit,
     }
     if cursor:
         params["cursor"] = cursor
@@ -265,9 +293,13 @@ def summary_data_api(
     id_token: str,
     field: str,
     term: str = "*",
+    latest_version: bool = True,
     size: int = 1000,
     cursor: Optional[str] = None,
 ) -> SummaryResponse:
+    if latest_version:
+        term += " AND latest_version:true"
+
     params = {
         "field": field,
         "query": term,
@@ -467,6 +499,37 @@ class DatasetRecord(BaseModel):
 
 
 # Factory Functions for Creating DataItem from DatasetRecord
+def _extract_metadata_from_property_values(
+    croissant_model: Optional[CroissantLiteModel],
+    field_names: List[str],
+) -> Dict[str, Any]:
+    """
+    Helper function to extract metadata from PropertyValue objects.
+
+    Args:
+        croissant_model: The Croissant Lite metadata model
+        field_names: List of field names to extract
+
+    Returns:
+        Dictionary mapping field_name -> value (as list if not already)
+    """
+    result = {}
+
+    if not croissant_model or not croissant_model.variable_measured:
+        return result
+
+    for field_name in field_names:
+        for pv in croissant_model.variable_measured:
+            if pv.name == field_name:
+                value = pv.value
+                if value is not None:
+                    # Ensure value is a list
+                    result[field_name] = value if isinstance(value, list) else [value]
+                break
+
+    return result
+
+
 def extract_biological_metadata(
     croissant_model: Optional[CroissantLiteModel],
 ) -> Dict[str, Any]:
@@ -475,40 +538,23 @@ def extract_biological_metadata(
 
     Returns a dict of field_name -> value suitable for CrossModalitySchemaFields.
     """
-    bio_fields = {}
+    field_names = list(CrossModalitySchemaFields.model_fields.keys())
+    return _extract_metadata_from_property_values(croissant_model, field_names)
 
-    if not croissant_model or not croissant_model.variable_measured:
-        return bio_fields
 
-    # Get field names from CrossModalitySchemaFields
-    xms_fields = CrossModalitySchemaFields.model_fields
+def extract_hcs_metadata(
+    croissant_model: Optional[CroissantLiteModel],
+) -> Dict[str, Any]:
+    """
+    Extract HCS metadata from CroissantLiteModel's variableMeasured.
 
-    for field_name in xms_fields.keys():
-        for pv in croissant_model.variable_measured:
-            if pv.name == field_name:
-                value = pv.value
-                if value is not None:
-                    # Check if field expects a list
-                    field_info = xms_fields[field_name]
-                    annotation = field_info.annotation
+    These are non-XMS fields that provide additional context for High Content
+    Screening (HCS) datasets like OrganelleBox.
 
-                    # Handle Optional[List[str]] type annotations
-                    if typing.get_origin(annotation) is Union:
-                        # Get the non-None type from Optional
-                        args = typing.get_args(annotation)
-                        annotation = next(
-                            (arg for arg in args if arg is not type(None)), annotation
-                        )
-
-                    if typing.get_origin(annotation) is list:
-                        bio_fields[field_name] = (
-                            value if isinstance(value, list) else [value]
-                        )
-                    else:
-                        bio_fields[field_name] = value
-                break
-
-    return bio_fields
+    Returns a dict of field_name -> value suitable for HcsMetadata.
+    """
+    field_names = list(HcsMetadata.model_fields.keys())
+    return _extract_metadata_from_property_values(croissant_model, field_names)
 
 
 def create_data_item_from_dataset(record: DatasetRecord) -> DataItem:
