@@ -8,6 +8,12 @@ from pydantic import BaseModel
 
 from .api import SearchResponse, search_data_api
 
+# Optional import for progress bar
+try:
+    from tqdm import tqdm
+except ImportError:
+    tqdm = None  # type: ignore[assignment]
+
 
 class DownloadCandidate(BaseModel):
     dataset_id: str
@@ -149,7 +155,11 @@ class DownloadDatabase:
         conn.close()
 
     def find_existing_candidates_db(self, query: str) -> Optional[Path]:
-        """Find existing non-expired candidates database for the given query."""
+        """Find existing non-expired candidates database for the given query.
+
+        Only returns databases that have at least one candidate to avoid
+        returning empty databases created by interrupted collection processes.
+        """
         now = datetime.now()
 
         for db_file in self.downloads_dir.glob("candidates_*.db"):
@@ -159,7 +169,6 @@ class DownloadDatabase:
                     SELECT query, expires_at FROM query_metadata LIMIT 1
                 """)
                 row = cursor.fetchone()
-                conn.close()
 
                 if row:
                     stored_query, expires_at_str = row
@@ -167,7 +176,21 @@ class DownloadDatabase:
 
                     # Check if query matches and not expired
                     if stored_query == query and expires_at > now:
-                        return db_file
+                        # Additionally check that the database has at least one candidate
+                        # to avoid returning empty databases from interrupted collections
+                        cursor = conn.execute("""
+                            SELECT COUNT(*) FROM download_candidates
+                        """)
+                        count_row = cursor.fetchone()
+                        conn.close()
+
+                        if count_row and count_row[0] > 0:
+                            return db_file
+                        else:
+                            # Empty database, skip it (will be cleaned up later or on next collection)
+                            continue
+
+                conn.close()
 
             except Exception:
                 # Skip corrupted databases
@@ -228,10 +251,20 @@ class DownloadDatabase:
             cursor = None
             total_collected = 0
             completed_successfully = False
+            pbar = None
 
             while True:
                 resp = search_data_api(id_token, query, limit, cursor, exact=exact)
 
+                # Initialize progress bar on first response when we know the total
+                if pbar is None and tqdm is not None and resp.total:
+                    pbar = tqdm(
+                        total=resp.total,
+                        desc="Collecting candidates",
+                        unit="candidates",
+                        unit_scale=False,
+                    )
+
                 candidates = []
                 for item in resp.data:
                     namespace = getattr(item, "namespace", None)
@@ -255,7 +288,7 @@ class DownloadDatabase:
                     # Insert without commit
                     conn.executemany(
                         """
-                        INSERT INTO download_candidates 
+                        INSERT INTO download_candidates
                         (dataset_id, dataset_name, namespace, location, downloaded)
                         VALUES (?, ?, ?, ?, ?)
                         """,
@@ -272,12 +305,20 @@ class DownloadDatabase:
                     )
                     total_collected += len(candidates)
 
+                    # Update progress bar
+                    if pbar is not None:
+                        pbar.update(len(candidates))
+
                 cursor = resp.cursor
                 last_page = resp.limit is not None and len(resp.data) < resp.limit
                 if last_page or not cursor:
                     completed_successfully = True
                     break
 
+            # Close progress bar
+            if pbar is not None:
+                pbar.close()
+
             if completed_successfully:
                 # Only commit if we completed the full search
                 conn.commit()
@@ -290,6 +331,9 @@ class DownloadDatabase:
                 raise Exception("Search collection was not completed successfully")
 
         except Exception as e:
+            # Close progress bar if it exists
+            if pbar is not None:
+                pbar.close()
             # Rollback and cleanup on any error or interruption
             conn.rollback()
             db_path.unlink(missing_ok=True)  # Remove incomplete database
